==> trend_etl-1.4.5-py3-none-any.whl: trend_etl/transform/guilds.py <==
from pyspark.sql import DataFrame

from pyspark.sql.functions import col, lit, get_json_object, named_struct
from pyspark.sql.types import StringType, BinaryType, TimestampType

import trend_etl.schema.fields as fields
from trend_etl.functions.index import (
    discord_snowflake_timestamp,
    get_created_day,
    parse_guilds,
)


#
# arguments:
#   input_df: dataframe received from reading a kafka topic
#   target_topic: source topic from kafka
# return: a dataframe in the schema expected for bronze tables
def from_kafka_get_bronze_guilds_df(
    input_df: DataFrame, target_topic: str
) -> DataFrame:
    snowflake_id = discord_snowflake_timestamp(
        get_json_object(col(fields.kafka_value_field).cast(StringType()), "$.id")
    )

    return input_df.select(
        col(fields.kafka_value_field).alias(fields.bronze_value_field),
        lit(f"kafka/{target_topic}").alias(fields.bronze_provenance_field),
        col(fields.kafka_timestamp_field).alias(fields.bronze_timestamp_field),
        get_created_day(snowflake_id).alias(fields.created_day_field),
    )


# arguments:
#   streaming_bronze: streaming dataframe from bronze table
#   guild_idents: guild uuid idents table
def from_bronze_get_guilds_df(
    streaming_bronze: DataFrame,
    guild_idents: DataFrame,
) -> DataFrame:
    parsed_df = streaming_bronze.select(
        parse_guilds(col(fields.bronze_value_field).cast(StringType())).alias("value"),
        col(fields.bronze_timestamp_field),
    )

    flattened_df = parsed_df.select(
        col("value.*"),
        col(fields.bronze_timestamp_field),
    )

    # join with guild_idents
    result_df = (
        flattened_df.join(
            guild_idents,
            "id",
            "left_outer",
        )
        .withColumn("created_at", discord_snowflake_timestamp(col("id")))
        .withColumn(fields.source_keys_field, named_struct(lit("id"), col("id")))
        .drop("id")
    )

    return result_df

==> trend_etl-1.4.14-py3-none-any.whl: trend_etl/transform/guilds.py <==
from pyspark.sql import DataFrame

from pyspark.sql.functions import col, lit, get_json_object, struct
from pyspark.sql.types import StringType

import trend_etl.schema.fields as fields
from trend_etl.functions.misc import get_created_day
from trend_etl.functions.udfs import discord_snowflake_timestamp
from trend_etl.functions.parsing import parse_guilds


#
# arguments:
#   input_df: dataframe received from reading a kafka topic
#   target_topic: source topic from kafka
# return: a dataframe in the schema expected for bronze tables
def from_kafka_get_bronze_guilds_df(
    input_df: DataFrame, target_topic: str
) -> DataFrame:
    snowflake_id = discord_snowflake_timestamp(
        get_json_object(col(fields.kafka_value_field).cast(StringType()), "$.id")
    )

    return input_df.select(
        col(fields.kafka_value_field).alias(fields.bronze_value_field),
        lit(f"kafka/{target_topic}").alias(fields.bronze_provenance_field),
        col(fields.kafka_timestamp_field).alias(fields.bronze_timestamp_field),
        get_created_day(snowflake_id).alias(fields.created_day_field),
    )


# arguments:
#   streaming_bronze: streaming dataframe from bronze table
#   guild_idents: guild uuid idents table
def from_bronze_get_guilds_df(
    streaming_bronze: DataFrame,
    guild_idents: DataFrame,
) -> DataFrame:
    parsed_df = streaming_bronze.select(
        parse_guilds(col(fields.bronze_value_field).cast(StringType())).alias("value"),
        col(fields.bronze_timestamp_field),
    )

    flattened_df = parsed_df.select(
        col("value.*"),
        col(fields.bronze_timestamp_field),
    )

    # join with guild_idents
    result_df = (
        flattened_df.join(
            guild_idents,
            "id",
            "left_outer",
        )
        .withColumn("created_at", discord_snowflake_timestamp(col("id")))
        .withColumn(fields.source_keys_field, struct(col("id").alias("id")))
        .drop("id")
    )

    return result_df
